@@ -1,6 +1,6 @@
+use rand::prelude::*;
 use std::io;
 use wordletron::*;
-use rand::prelude::*;
 
 fn main() -> io::Result<()> {
     let (mut answers, guesses) = load_words();
@@ -9,8 +9,14 @@ fn main() -> io::Result<()> {
 
     let answer = answers.choose(&mut rand::thread_rng()).unwrap().clone();
 
+    let mut letters = String::from("abcdefghijklmnopqrstuvwxyz");
+
+    let mut hangman = Word::try_from("_____").unwrap();
+
     while sequence.len() < 6 && sequence.last() != Some(&answer) {
         println!("possible answers: {}", answers.len());
+        println!("available letters: {}", letters);
+        println!("answer so far: {}", hangman);
         match get_guess() {
             Ok(g) => guess = g,
             Err(e) => {
@@ -23,6 +29,13 @@ fn main() -> io::Result<()> {
             continue;
         }
         let clue = compute_clue(&answer, &guess);
+        for (i, _) in clue.iter().enumerate() {
+            if clue[i] == Black {
+                letters = letters.replace(guess[i] as char, "");
+            } else if clue[i] == Green {
+                hangman[i] = guess[i];
+            }
+        }
         println!("clue: {}", clue);
         answers.retain(|a| is_candidate(&clue, &guess, a));
         sequence.push(guess);
